==> jc-1.4.0.tar.gz: java/net/UnknownHostException.h <==
// public class java.net.UnknownHostException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 49d704cff607029c java_net_UnknownHostException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_net_UnknownHostException_H_
#define _JC_java_net_UnknownHostException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_UnknownHostException$sub_refs	_jc_java_net_UnknownHostException$sub_refs;
typedef struct _jc_java_net_UnknownHostException$sub_nonrefs	_jc_java_net_UnknownHostException$sub_nonrefs;
typedef struct _jc_java_net_UnknownHostException$refs	_jc_java_net_UnknownHostException$refs;
typedef struct _jc_java_net_UnknownHostException$nonrefs	_jc_java_net_UnknownHostException$nonrefs;
typedef struct _jc_java_net_UnknownHostException$object	_jc_java_net_UnknownHostException$object;

typedef struct _jc_java_net_UnknownHostException$fields_struct	_jc_java_net_UnknownHostException$fields_struct;
typedef const struct _jc_java_net_UnknownHostException$vmethods	_jc_java_net_UnknownHostException$vmethods;
typedef const struct _jc_java_net_UnknownHostException$vtable	_jc_java_net_UnknownHostException$vtable;
typedef const struct _jc_java_net_UnknownHostException$vtype	_jc_java_net_UnknownHostException$vtype;

// Class fields structure
struct _jc_java_net_UnknownHostException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_UnknownHostException$fields_struct _jc_java_net_UnknownHostException$class_fields;

// Constructors
extern void _jc_java_net_UnknownHostException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_UnknownHostException$object *);
extern void _jc_java_net_UnknownHostException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_UnknownHostException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_UnknownHostException$vmethods {
};

// Vtable
struct _jc_java_net_UnknownHostException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_UnknownHostException$vmethods	java_net_UnknownHostException;
};

// Vtype
struct _jc_java_net_UnknownHostException$vtype {
	_jc_type			type;
	_jc_java_net_UnknownHostException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_UnknownHostException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_UnknownHostException$refs {
    _jc_java_net_UnknownHostException$sub_refs	java_net_UnknownHostException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_UnknownHostException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_UnknownHostException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_UnknownHostException$sub_nonrefs	java_net_UnknownHostException;
};

// Object instance structure
struct _jc_java_net_UnknownHostException$object {
	_jc_java_net_UnknownHostException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_UnknownHostException$vtype	*vtype;
	_jc_java_net_UnknownHostException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_UnknownHostException$vtype _jc_java_net_UnknownHostException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_UnknownHostException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_UnknownHostException$class_object;

#endif	/* _JC_java_net_UnknownHostException_H_ */

==> jc-1.4.6.tar.gz: java/net/UnknownHostException.h <==
// public class java.net.UnknownHostException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 49d704cff607029c java_net_UnknownHostException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_net_UnknownHostException_H_
#define _JC_java_net_UnknownHostException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_UnknownHostException$sub_refs	_jc_java_net_UnknownHostException$sub_refs;
typedef struct _jc_java_net_UnknownHostException$sub_nonrefs	_jc_java_net_UnknownHostException$sub_nonrefs;
typedef struct _jc_java_net_UnknownHostException$refs	_jc_java_net_UnknownHostException$refs;
typedef struct _jc_java_net_UnknownHostException$nonrefs	_jc_java_net_UnknownHostException$nonrefs;
typedef struct _jc_java_net_UnknownHostException$object	_jc_java_net_UnknownHostException$object;

typedef struct _jc_java_net_UnknownHostException$fields_struct	_jc_java_net_UnknownHostException$fields_struct;
typedef const struct _jc_java_net_UnknownHostException$vmethods	_jc_java_net_UnknownHostException$vmethods;
typedef const struct _jc_java_net_UnknownHostException$vtable	_jc_java_net_UnknownHostException$vtable;
typedef const struct _jc_java_net_UnknownHostException$vtype	_jc_java_net_UnknownHostException$vtype;

// Class fields structure
struct _jc_java_net_UnknownHostException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_UnknownHostException$fields_struct _jc_java_net_UnknownHostException$class_fields;

// Constructors
extern void _jc_java_net_UnknownHostException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_UnknownHostException$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_UnknownHostException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_UnknownHostException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_UnknownHostException$vmethods {
};

// Vtable
struct _jc_java_net_UnknownHostException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_UnknownHostException$vmethods	java_net_UnknownHostException;
};

// Vtype
struct _jc_java_net_UnknownHostException$vtype {
	_jc_type			type;
	_jc_java_net_UnknownHostException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_UnknownHostException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_UnknownHostException$refs {
    _jc_java_net_UnknownHostException$sub_refs	java_net_UnknownHostException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_UnknownHostException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_UnknownHostException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_UnknownHostException$sub_nonrefs	java_net_UnknownHostException;
};

// Object instance structure
struct _jc_java_net_UnknownHostException$object {
	_jc_java_net_UnknownHostException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_UnknownHostException$vtype	*vtype;
	_jc_java_net_UnknownHostException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_UnknownHostException$vtype _jc_java_net_UnknownHostException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_UnknownHostException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_UnknownHostException$class_object;

#endif	/* _JC_java_net_UnknownHostException_H_ */
